==> Shannon-Entropy-1.101010.tar.gz: Shannon-Entropy-1.101010/lib/Shannon/Entropy.pm <==
package Shannon::Entropy;

use 5.006;
use strict;
use warnings;

use Import::Export;

use base qw/Import::Export/;

our $VERSION = '1.101010';

our %EX = (
	entropy => [qw/all/]
);

sub entropy {
	my ($entropy, $len, $p, %t) = (0, length($_[0]));
	return (map { $p = $_/$len; $entropy -= $p * log $p } (map { $t{$_}++ } split '', $_[0]) ? values %t : () and $entropy / log 2);
}

=head1 NAME

Shannon::Entropy - Calculate the Shannon entropy H of a given input string.

=head1 VERSION

Version 1.101010

=cut

=head1 SYNOPSIS

Calculate the Shannon entropy H of a given input string.

	use Shannon::Entropy qw/entropy/;

	entropy('1223334444'); # 1.8464393446710154
	entropy('0123456789abcdef'); # 4

=head2 entropy

=head1 AUTHOR

Robert Acock, C<< <thisusedtobeanemail at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-shannon-entropy at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Shannon-Entropy>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Shannon::Entropy

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Shannon-Entropy>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Shannon-Entropy>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Shannon-Entropy>

=item * Search CPAN

L<http://search.cpan.org/dist/Shannon-Entropy/>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

Copyright 2018 Robert Acock.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of Shannon::Entropy

==> Shannon-Entropy-1.101011.tar.gz: Shannon-Entropy-1.101011/lib/Shannon/Entropy.pm <==
package Shannon::Entropy;

use 5.006;
use strict;
use warnings;

use Import::Export;

use base qw/Import::Export/;

our $VERSION = '1.101011';

our %EX = (
	entropy => [qw/all/]
);

sub entropy {
	my ($entropy, $len, $p, %t) = (0, length($_[0]));
	$t{$_}++ foreach split '', $_[0];
	foreach (values %t) {
		$p = $_/$len;
		$entropy -= $p * log $p;
	} 
	return $entropy / log 2;
}

1;

__END__

=head1 NAME

Shannon::Entropy - Calculate the Shannon entropy H of a given input string.

=head1 VERSION

Version 1.101011

=cut

=head1 SYNOPSIS

Calculate the Shannon entropy H of a given input string.

	use Shannon::Entropy qw/entropy/;

	entropy('1223334444'); # 1.8464393446710154
	entropy('0123456789abcdef'); # 4

=head2 entropy

=head1 AUTHOR

Robert Acock, C<< <thisusedtobeanemail at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-shannon-entropy at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Shannon-Entropy>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

	perldoc Shannon::Entropy

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Shannon-Entropy>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Shannon-Entropy>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Shannon-Entropy>

=item * Search CPAN

L<http://search.cpan.org/dist/Shannon-Entropy/>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

Copyright 2018 Robert Acock.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut
